@@ -109,6 +109,8 @@ def normalize_columns(df: pd.DataFrame):
 
         columnName = columnName.replace(" ", "_")
         columnName = columnName.replace("-", "_")
+        columnName = columnName.replace("/", "_")
+        columnName = columnName.replace("\\", "_")
         columnName = columnName.replace("%", "perc")
         columnName = columnName.replace("+", "plus")
         columnName = columnName.replace("&", "and")
