@@ -441,9 +441,6 @@ class Query:
             if isinstance(where_condition, Condition):
                 if where_condition.field.column is not None:
                     vars = []
-                    negation = None
-                    if where_condition.negate is not None:
-                        negation = "NOT"
 
                     if where_condition.value is not None:
                         for var in where_condition.value:
@@ -523,41 +520,26 @@ class Query:
                         conditions.append(formatted_cond)
                     else:
                         if formatted_value is not None and where_condition.direction is None:
-                            if where_condition.negate is None:
-                                formatted_cond = field_with_agg + " " + operator + " " + str(formatted_value)
-
-                            else:
-                                formatted_cond = field_with_agg + " " + negation + " " + operator + " " + str(formatted_value)
+                            formatted_cond = field_with_agg + " " + operator + " " + str(formatted_value)
                         elif formatted_value is None and where_condition.direction is not None:
                             if isinstance(where_condition.direction, PeriodOperator):
                                 direction = where_condition.direction.name
                             else:
                                 direction = where_condition.direction
-                            if negation is None:
-                                if where_condition.steps is not None and where_condition.interval is not None:
-                                    formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
-                                elif where_condition.steps is not None and where_condition.interval is None:
-                                    formatted_cond = (
-                                            field_with_agg + " " + operator + " " + direction + " " + where_condition.steps
-                                    )
-                                elif where_condition.steps is None and where_condition.interval is not None:
-                                    formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction
-                                else:
-                                    formatted_cond = field_with_agg + " " + operator + " " + direction
+
+                            if where_condition.steps is not None and where_condition.interval is not None:
+                                formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
+                            elif where_condition.steps is not None and where_condition.interval is None:
+                                formatted_cond = (
+                                        field_with_agg + " " + operator + " " + direction + " " + where_condition.steps
+                                )
+                            elif where_condition.steps is None and where_condition.interval is not None:
+                                formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction
                             else:
-                                if where_condition.steps is not None and where_condition.interval is not None:
-                                    formatted_cond = field_with_agg + " " + negation + " " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
-                                elif where_condition.steps is not None and where_condition.interval is None:
-                                    formatted_cond = field_with_agg + " " + negation + " " + operator + " " + direction + " " + where_condition.steps
-                                elif where_condition.steps is None and where_condition.interval is not None:
-                                    formatted_cond = field_with_agg + " " + negation + " " + operator + " " + where_condition.interval + " " + direction
-                                else:
-                                    formatted_cond = field_with_agg + " " + negation + " " + operator + " " + direction
+                                formatted_cond = field_with_agg + " " + operator + " " + direction
+
                         elif operator is not None:
-                            if negation is None:
-                                formatted_cond = field_with_agg + " " + operator
-                            else:
-                                formatted_cond = field_with_agg + " " + negation + " " + operator
+                            formatted_cond = field_with_agg + " " + operator
                         else:
                             formatted_cond = field_with_agg
                         conditions.append(formatted_cond)
